<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>Unidad en dibujos nuevos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Default Linetype</source>
        <translation type="obsolete">Tipo de línea por defecto</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>Tipo de línea</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>Escala mundial de tipos de línea:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>La escala de los tipos de línea coincide con la escala de cada ventana de visualización</translation>
    </message>
    <message>
        <source>Use screen based line patterns for model space view</source>
        <translation type="obsolete">Usar patrones de línea base de la pantalla de vista de espacio modelo</translation>
    </message>
</context>
</TS>
